@@ -9,7 +9,7 @@ use Mojo::UserAgent;
 
 use vars qw($DEBUG $CACHE);
 
-our $VERSION = '1.01_01';
+our $VERSION = '1.01';
 
 our %searches = (
 	cities                              => 'cities?',
@@ -209,10 +209,10 @@ sub url {
 	$self->{url};
 	}
 
-sub _build_request_url {
+sub _build_request {
 	my( $self, $request, @args ) = @_;
 	my $hash = { @args, username => $self->username };
-	my $request_url = $self->url . '/' . $searches{$request};
+	my $request_string = $self->url . '/' . $searches{$request};
 
 	# check to see that mandatory arguments are present
 	my $conditional_mandatory_flag = 0;
@@ -245,11 +245,11 @@ sub _build_request_url {
 		carp("Invalid argument $key") if(!defined($valid_parameters{$request}->{$key}));
 		my @vals = ref($hash->{$key}) ? @{$hash->{$key}} : $hash->{$key};
 		no warnings 'uninitialized';
-		$request_url .= join("", map { "$key=$_&" } @vals );
+		$request_string .= join("", map { "$key=$_&" } @vals );
 		}
 
-	chop($request_url); # loose the trailing &
-	return $request_url;
+	chop($request_string); # loose the trailing &
+	return $request_string;
 	}
 
 sub _parse_xml_result {
@@ -329,12 +329,12 @@ sub _request {
 sub _do_search {
 	my( $self, $searchtype, @args ) = @_;
 
-	my $request_url = $self->_build_request_url( $searchtype, @args );
-	my $response = $self->_request( $request_url );
+	my $request = $self->_build_request( $searchtype, @args );
+	my $response = $self->_request( $request );
 
 	# check mime-type to determine which parse method to use.
 	# we accept text/xml, text/plain (how do see if it is JSON or not?)
-	my $mime_type = $response->headers->content_type || '';
+	my $mime_type = $response->headers->header( 'Content-type' );
 
 	if($mime_type =~ m(\Atext/xml;) ) {
 		return $self->_parse_xml_result( $response->body );
@@ -351,9 +351,9 @@ sub _do_search {
 			}
 		}
 
-	carp "Invalid mime type [$mime_type]. Maybe you aren't connected.";
+	carp "Invalid mime type [$mime_type]";
 
-	return [];
+	return;
 	}
 
 sub geocode {
